Class: Google::Cloud::Workstations::V1beta::CreateWorkstationClusterRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

Message for creating a CreateWorkstationCluster.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. Parent resource name.

Returns:

  • (::String)

    Required. Parent resource name.



1389
1390
1391
1392
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1389

class CreateWorkstationClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. If set, validate the request and preview the result, but do not actually apply it.

Returns:

  • (::Boolean)

    Optional. If set, validate the request and preview the result, but do not actually apply it.



1389
1390
1391
1392
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1389

class CreateWorkstationClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#workstation_cluster::Google::Cloud::Workstations::V1beta::WorkstationCluster

Returns Required. Workstation cluster to create.

Returns:



1389
1390
1391
1392
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1389

class CreateWorkstationClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#workstation_cluster_id::String

Returns Required. ID to use for the workstation cluster.

Returns:

  • (::String)

    Required. ID to use for the workstation cluster.



1389
1390
1391
1392
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1389

class CreateWorkstationClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end