Class: Google::Cloud::Workstations::V1beta::DeleteWorkstationConfigRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::DeleteWorkstationConfigRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
Message for deleting a workstation configuration.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. If set, the request is rejected if the latest version of the workstation configuration on the server does not have this ETag.
1573 1574 1575 1576 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1573 class DeleteWorkstationConfigRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#force ⇒ ::Boolean
Returns Optional. If set, any workstations in the workstation configuration are also deleted. Otherwise, the request works only if the workstation configuration has no workstations.
1573 1574 1575 1576 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1573 class DeleteWorkstationConfigRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Name of the workstation configuration to delete.
1573 1574 1575 1576 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1573 class DeleteWorkstationConfigRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. If set, validate the request and preview the result, but do not actually apply it.
1573 1574 1575 1576 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1573 class DeleteWorkstationConfigRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |