Class: Google::Cloud::Workstations::V1beta::DeleteWorkstationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

Request message for DeleteWorkstation.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag.

Returns:

  • (::String)

    Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag.



1711
1712
1713
1714
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1711

class DeleteWorkstationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. Name of the workstation to delete.

Returns:

  • (::String)

    Required. Name of the workstation to delete.



1711
1712
1713
1714
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1711

class DeleteWorkstationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. If set, validate the request and preview the result, but do not actually apply it.

Returns:

  • (::Boolean)

    Optional. If set, validate the request and preview the result, but do not actually apply it.



1711
1712
1713
1714
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1711

class DeleteWorkstationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end