Class: Google::Cloud::Workstations::V1beta::GenerateAccessTokenRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

Request message for GenerateAccessToken.

Instance Attribute Summary collapse

Instance Attribute Details

#expire_time::Google::Protobuf::Timestamp

Returns Desired expiration time of the access token. This value must be at most 24 hours in the future. If a value is not specified, the token's expiration time will be set to a default value of 1 hour in the future.

Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Timestamp)

    Desired expiration time of the access token. This value must be at most 24 hours in the future. If a value is not specified, the token's expiration time will be set to a default value of 1 hour in the future.

    Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.



1781
1782
1783
1784
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1781

class GenerateAccessTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#port::Integer

Returns Optional. Port for which the access token should be generated. If specified, the generated access token grants access only to the specified port of the workstation. If specified, values must be within the range [1 - 65535]. If not specified, the generated access token grants access to all ports of the workstation.

Returns:

  • (::Integer)

    Optional. Port for which the access token should be generated. If specified, the generated access token grants access only to the specified port of the workstation. If specified, values must be within the range [1 - 65535]. If not specified, the generated access token grants access to all ports of the workstation.



1781
1782
1783
1784
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1781

class GenerateAccessTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ttl::Google::Protobuf::Duration

Returns Desired lifetime duration of the access token. This value must be at most 24 hours. If a value is not specified, the token's lifetime will be set to a default value of 1 hour.

Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Duration)

    Desired lifetime duration of the access token. This value must be at most 24 hours. If a value is not specified, the token's lifetime will be set to a default value of 1 hour.

    Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.



1781
1782
1783
1784
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1781

class GenerateAccessTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#workstation::String

Returns Required. Name of the workstation for which the access token should be generated.

Returns:

  • (::String)

    Required. Name of the workstation for which the access token should be generated.



1781
1782
1783
1784
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1781

class GenerateAccessTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end