Class: Google::Cloud::Workstations::V1beta::ListUsableWorkstationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::ListUsableWorkstationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
Response message for ListUsableWorkstations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ ::Array<::String>
Unreachable resources.
-
#workstations ⇒ ::Array<::Google::Cloud::Workstations::V1beta::Workstation>
The requested workstations.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Token to retrieve the next page of results, or empty if there are no more results in the list.
1650 1651 1652 1653 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1650 class ListUsableWorkstationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unreachable resources.
1650 1651 1652 1653 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1650 class ListUsableWorkstationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#workstations ⇒ ::Array<::Google::Cloud::Workstations::V1beta::Workstation>
Returns The requested workstations.
1650 1651 1652 1653 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1650 class ListUsableWorkstationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |