Class: Google::Cloud::Workstations::V1beta::ListWorkstationClustersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

Request message for ListWorkstationClusters.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter the WorkstationClusters to be listed. Possible filters are described in https://google.aip.dev/160.

Returns:

  • (::String)

    Optional. Filter the WorkstationClusters to be listed. Possible filters are described in https://google.aip.dev/160.



1354
1355
1356
1357
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1354

class ListWorkstationClustersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Maximum number of items to return.

Returns:

  • (::Integer)

    Optional. Maximum number of items to return.



1354
1355
1356
1357
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1354

class ListWorkstationClustersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. next_page_token value returned from a previous List request, if any.

Returns:

  • (::String)

    Optional. next_page_token value returned from a previous List request, if any.



1354
1355
1356
1357
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1354

class ListWorkstationClustersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent resource name.

Returns:

  • (::String)

    Required. Parent resource name.



1354
1355
1356
1357
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1354

class ListWorkstationClustersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end