Class: Google::Cloud::Workstations::V1beta::PushCredentialsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

Request message for PushCredentials.

Defined Under Namespace

Classes: OAuthToken

Instance Attribute Summary collapse

Instance Attribute Details

#application_default_credentials::Google::Cloud::Workstations::V1beta::PushCredentialsRequest::OAuthToken

Returns Optional. Credentials used by Cloud Client Libraries, Google API Client Libraries, and other tooling within the user conainer: https://cloud.google.com/docs/authentication/application-default-credentials.

Returns:



1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1811

class PushCredentialsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # OAuth token.
  # @!attribute [rw] email
  #   @return [::String]
  #     Optional. The email address encapsulated in the OAuth token.
  # @!attribute [rw] scopes
  #   @return [::String]
  #     Optional. The scopes encapsulated in the OAuth token.
  #     See https://developers.google.com/identity/protocols/oauth2/scopes for
  #     more information.
  # @!attribute [rw] access_token
  #   @return [::String]
  #     Required. The OAuth token.
  # @!attribute [rw] expire_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time the OAuth access token will expire. This should be the
  #     time the access token was generated plus the expires_in offset returned
  #     from the Access Token Response.
  class OAuthToken
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#workstation::String

Returns Required. Name of the workstation for which the credentials should be pushed.

Returns:

  • (::String)

    Required. Name of the workstation for which the credentials should be pushed.



1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1811

class PushCredentialsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # OAuth token.
  # @!attribute [rw] email
  #   @return [::String]
  #     Optional. The email address encapsulated in the OAuth token.
  # @!attribute [rw] scopes
  #   @return [::String]
  #     Optional. The scopes encapsulated in the OAuth token.
  #     See https://developers.google.com/identity/protocols/oauth2/scopes for
  #     more information.
  # @!attribute [rw] access_token
  #   @return [::String]
  #     Required. The OAuth token.
  # @!attribute [rw] expire_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time the OAuth access token will expire. This should be the
  #     time the access token was generated plus the expires_in offset returned
  #     from the Access Token Response.
  class OAuthToken
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end