Class: Google::Cloud::Workstations::V1beta::PushCredentialsRequest::OAuthToken

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

OAuth token.

Instance Attribute Summary collapse

Instance Attribute Details

#access_token::String

Returns Required. The OAuth token.

Returns:

  • (::String)

    Required. The OAuth token.



1832
1833
1834
1835
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1832

class OAuthToken
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#email::String

Returns Optional. The email address encapsulated in the OAuth token.

Returns:

  • (::String)

    Optional. The email address encapsulated in the OAuth token.



1832
1833
1834
1835
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1832

class OAuthToken
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expire_time::Google::Protobuf::Timestamp

Returns Optional. The time the OAuth access token will expire. This should be the time the access token was generated plus the expires_in offset returned from the Access Token Response.

Returns:

  • (::Google::Protobuf::Timestamp)

    Optional. The time the OAuth access token will expire. This should be the time the access token was generated plus the expires_in offset returned from the Access Token Response.



1832
1833
1834
1835
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1832

class OAuthToken
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scopes::String

Returns Optional. The scopes encapsulated in the OAuth token. See https://developers.google.com/identity/protocols/oauth2/scopes for more information.

Returns:



1832
1833
1834
1835
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1832

class OAuthToken
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end