Class: Google::Cloud::Workstations::V1beta::StartWorkstationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

Request message for StartWorkstation.

Instance Attribute Summary collapse

Instance Attribute Details

#boost_config::String

Returns Optional. If set, the workstation starts using the boost configuration with the specified ID.

Returns:

  • (::String)

    Optional. If set, the workstation starts using the boost configuration with the specified ID.



1732
1733
1734
1735
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1732

class StartWorkstationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#etag::String

Returns Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag.

Returns:

  • (::String)

    Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag.



1732
1733
1734
1735
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1732

class StartWorkstationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. Name of the workstation to start.

Returns:

  • (::String)

    Required. Name of the workstation to start.



1732
1733
1734
1735
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1732

class StartWorkstationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. If set, validate the request and preview the result, but do not actually apply it.

Returns:

  • (::Boolean)

    Optional. If set, validate the request and preview the result, but do not actually apply it.



1732
1733
1734
1735
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1732

class StartWorkstationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end