Class: Google::Cloud::Workstations::V1beta::UpdateWorkstationClusterRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

Request message for UpdateWorkstationCluster.

Instance Attribute Summary collapse

Instance Attribute Details

#allow_missing::Boolean

Returns Optional. If set, and the workstation cluster is not found, a new workstation cluster will be created. In this situation, update_mask is ignored.

Returns:

  • (::Boolean)

    Optional. If set, and the workstation cluster is not found, a new workstation cluster will be created. In this situation, update_mask is ignored.



1411
1412
1413
1414
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1411

class UpdateWorkstationClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Required. Mask that specifies which fields in the workstation cluster should be updated.

Returns:



1411
1412
1413
1414
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1411

class UpdateWorkstationClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. If set, validate the request and preview the result, but do not actually apply it.

Returns:

  • (::Boolean)

    Optional. If set, validate the request and preview the result, but do not actually apply it.



1411
1412
1413
1414
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1411

class UpdateWorkstationClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#workstation_cluster::Google::Cloud::Workstations::V1beta::WorkstationCluster

Returns Required. Workstation cluster to update.

Returns:



1411
1412
1413
1414
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1411

class UpdateWorkstationClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end