Class: Google::Cloud::Workstations::V1beta::UpdateWorkstationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::UpdateWorkstationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
Request message for UpdateWorkstation.
Instance Attribute Summary collapse
-
#allow_missing ⇒ ::Boolean
Optional.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Required.
-
#validate_only ⇒ ::Boolean
Optional.
-
#workstation ⇒ ::Google::Cloud::Workstations::V1beta::Workstation
Required.
Instance Attribute Details
#allow_missing ⇒ ::Boolean
Returns Optional. If set and the workstation is not found, a new workstation is created. In this situation, update_mask is ignored.
1694 1695 1696 1697 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1694 class UpdateWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Required. Mask specifying which fields in the workstation should be updated.
1694 1695 1696 1697 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1694 class UpdateWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. If set, validate the request and preview the result, but do not actually apply it.
1694 1695 1696 1697 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1694 class UpdateWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#workstation ⇒ ::Google::Cloud::Workstations::V1beta::Workstation
Returns Required. Workstation to update.
1694 1695 1696 1697 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1694 class UpdateWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |