Class: Google::Cloud::Workstations::V1beta::Workstation::WorkstationBoostConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

Boost configuration for this workstation. This object is populated from the parent workstation configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#id::String (readonly)

Returns Output only. Boost configuration ID.

Returns:

  • (::String)

    Output only. Boost configuration ID.



1253
1254
1255
1256
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1253

class WorkstationBoostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#running::Boolean (readonly)

Returns Output only. Whether or not the current workstation is actively boosted with this id.

Returns:

  • (::Boolean)

    Output only. Whether or not the current workstation is actively boosted with this id.



1253
1254
1255
1256
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1253

class WorkstationBoostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end