Class: Google::Cloud::Workstations::V1beta::Workstation::WorkstationPersistentDirectory

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

A directory to persist across workstation sessions. Updates to this field will only take effect on this workstation after it is restarted.

Instance Attribute Summary collapse

Instance Attribute Details

#mount_path::String

Returns Optional. The mount path of the persistent directory.

Returns:

  • (::String)

    Optional. The mount path of the persistent directory.



1239
1240
1241
1242
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1239

class WorkstationPersistentDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#size_gb::Integer

Returns Optional. Size of the persistent directory in GB. If specified in an update request, this is the desired size of the directory.

Returns:

  • (::Integer)

    Optional. Size of the persistent directory in GB. If specified in an update request, this is the desired size of the directory.



1239
1240
1241
1242
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1239

class WorkstationPersistentDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end