Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::Container

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

A Docker container.

Defined Under Namespace

Classes: EnvEntry

Instance Attribute Summary collapse

Instance Attribute Details

#args::Array<::String>

Returns Optional. Arguments passed to the entrypoint.

Returns:

  • (::Array<::String>)

    Optional. Arguments passed to the entrypoint.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1021

class Container
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#command::Array<::String>

Returns Optional. If set, overrides the default ENTRYPOINT specified by the image.

Returns:

  • (::Array<::String>)

    Optional. If set, overrides the default ENTRYPOINT specified by the image.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1021

class Container
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#env::Google::Protobuf::Map{::String => ::String}

Returns Optional. Environment variables passed to the container's entrypoint.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Environment variables passed to the container's entrypoint.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1021

class Container
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#image::String

Returns Optional. A Docker container image that defines a custom environment.

Cloud Workstations provides a number of preconfigured images, but you can create your own custom container images. If using a private image, the host.gceInstance.serviceAccount field must be specified in the workstation configuration. If using a custom container image, the service account must have Artifact Registry Reader permission to pull the specified image. Otherwise, the image must be publicly accessible.

Returns:

  • (::String)

    Optional. A Docker container image that defines a custom environment.

    Cloud Workstations provides a number of preconfigured images, but you can create your own custom container images. If using a private image, the host.gceInstance.serviceAccount field must be specified in the workstation configuration. If using a custom container image, the service account must have Artifact Registry Reader permission to pull the specified image. Otherwise, the image must be publicly accessible.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1021

class Container
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#run_as_user::Integer

Returns Optional. If set, overrides the USER specified in the image with the given uid.

Returns:

  • (::Integer)

    Optional. If set, overrides the USER specified in the image with the given uid.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1021

class Container
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#working_dir::String

Returns Optional. If set, overrides the default DIR specified by the image.

Returns:

  • (::String)

    Optional. If set, overrides the default DIR specified by the image.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1021

class Container
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end