Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

An ephemeral directory which won't persist across workstation sessions. It is freshly created on every workstation start operation.

Defined Under Namespace

Classes: GcePersistentDisk

Instance Attribute Summary collapse

Instance Attribute Details

#gce_pd::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk

Returns An EphemeralDirectory backed by a Compute Engine persistent disk.

Returns:



932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 932

class EphemeralDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An EphemeralDirectory is backed by a Compute Engine persistent disk.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. Type of the disk to use. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. Must
  #     be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_image source_image}
  #     is set. Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#read_only read_only}
  #     is false. Updating
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     will update content in the ephemeral directory after the workstation is
  #     restarted.
  #
  #     Only file systems supported by Container-Optimized OS (COS)
  #     are explicitly supported. For a list of supported file systems, see
  #     [the filesystems available in Container-Optimized
  #     OS](https://cloud.google.com/container-optimized-os/docs/concepts/supported-filesystems).
  #
  #     This field is mutable.
  # @!attribute [rw] source_image
  #   @return [::String]
  #     Optional. Name of the disk image to use as the source for the disk.
  #     Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     is set. Updating
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_image source_image}
  #     will update content in the ephemeral directory after the workstation is
  #     restarted.
  #
  #     Only file systems supported by Container-Optimized OS (COS)
  #     are explicitly supported. For a list of supported file systems, please
  #     refer to the [COS
  #     documentation](https://cloud.google.com/container-optimized-os/docs/concepts/supported-filesystems).
  #
  #     This field is mutable.
  # @!attribute [rw] read_only
  #   @return [::Boolean]
  #     Optional. Whether the disk is read only. If true, the disk may be
  #     shared by multiple VMs and
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     must be set.
  class GcePersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#mount_path::String

Returns Required. Location of this directory in the running workstation.

Returns:

  • (::String)

    Required. Location of this directory in the running workstation.



932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 932

class EphemeralDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An EphemeralDirectory is backed by a Compute Engine persistent disk.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. Type of the disk to use. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. Must
  #     be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_image source_image}
  #     is set. Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#read_only read_only}
  #     is false. Updating
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     will update content in the ephemeral directory after the workstation is
  #     restarted.
  #
  #     Only file systems supported by Container-Optimized OS (COS)
  #     are explicitly supported. For a list of supported file systems, see
  #     [the filesystems available in Container-Optimized
  #     OS](https://cloud.google.com/container-optimized-os/docs/concepts/supported-filesystems).
  #
  #     This field is mutable.
  # @!attribute [rw] source_image
  #   @return [::String]
  #     Optional. Name of the disk image to use as the source for the disk.
  #     Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     is set. Updating
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_image source_image}
  #     will update content in the ephemeral directory after the workstation is
  #     restarted.
  #
  #     Only file systems supported by Container-Optimized OS (COS)
  #     are explicitly supported. For a list of supported file systems, please
  #     refer to the [COS
  #     documentation](https://cloud.google.com/container-optimized-os/docs/concepts/supported-filesystems).
  #
  #     This field is mutable.
  # @!attribute [rw] read_only
  #   @return [::Boolean]
  #     Optional. Whether the disk is read only. If true, the disk may be
  #     shared by multiple VMs and
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     must be set.
  class GcePersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end