Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::EphemeralDirectory::GcePersistentDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

An EphemeralDirectory is backed by a Compute Engine persistent disk.

Instance Attribute Summary collapse

Instance Attribute Details

#disk_type::String

Returns Optional. Type of the disk to use. Defaults to "pd-standard".

Returns:

  • (::String)

    Optional. Type of the disk to use. Defaults to "pd-standard".



980
981
982
983
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 980

class GcePersistentDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#read_only::Boolean

Returns Optional. Whether the disk is read only. If true, the disk may be shared by multiple VMs and source_snapshot must be set.

Returns:

  • (::Boolean)

    Optional. Whether the disk is read only. If true, the disk may be shared by multiple VMs and source_snapshot must be set.



980
981
982
983
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 980

class GcePersistentDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_image::String

Returns Optional. Name of the disk image to use as the source for the disk. Must be empty if source_snapshot is set. Updating source_image will update content in the ephemeral directory after the workstation is restarted.

Only file systems supported by Container-Optimized OS (COS) are explicitly supported. For a list of supported file systems, please refer to the COS documentation.

This field is mutable.

Returns:

  • (::String)

    Optional. Name of the disk image to use as the source for the disk. Must be empty if source_snapshot is set. Updating source_image will update content in the ephemeral directory after the workstation is restarted.

    Only file systems supported by Container-Optimized OS (COS) are explicitly supported. For a list of supported file systems, please refer to the COS documentation.

    This field is mutable.



980
981
982
983
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 980

class GcePersistentDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_snapshot::String

Returns Optional. Name of the snapshot to use as the source for the disk. Must be empty if source_image is set. Must be empty if read_only is false. Updating source_snapshot will update content in the ephemeral directory after the workstation is restarted.

Only file systems supported by Container-Optimized OS (COS) are explicitly supported. For a list of supported file systems, see the filesystems available in Container-Optimized OS.

This field is mutable.

Returns:

  • (::String)

    Optional. Name of the snapshot to use as the source for the disk. Must be empty if source_image is set. Must be empty if read_only is false. Updating source_snapshot will update content in the ephemeral directory after the workstation is restarted.

    Only file systems supported by Container-Optimized OS (COS) are explicitly supported. For a list of supported file systems, see the filesystems available in Container-Optimized OS.

    This field is mutable.



980
981
982
983
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 980

class GcePersistentDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end