Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

A directory to persist across workstation sessions. Updates to this field will not update existing workstations and will only take effect on new workstations.

Defined Under Namespace

Classes: GceHyperdiskBalancedHighAvailability, GceRegionalPersistentDisk

Instance Attribute Summary collapse

Instance Attribute Details

#gce_hd::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability

Returns A PersistentDirectory backed by a Compute Engine hyperdisk high availability disk.

Note: The following fields are mutually exclusive: gce_hd, gce_pd. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 781

class PersistentDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Persistent Directory backed by a Compute Engine regional persistent
  # disk. The
  # {::Google::Cloud::Workstations::V1beta::WorkstationConfig#persistent_directories persistent_directories}
  # field is repeated, but it may contain only one entry. It creates a
  # [persistent
  # disk](https://cloud.google.com/compute/docs/disks/persistent-disks) that
  # mounts to the workstation VM at `/home` when the session starts and
  # detaches when the session ends. If this field is empty, workstations
  # created with this configuration do not have a persistent home
  # directory.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`. If less than `200` GB, the
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#disk_type disk_type}
  #     must be
  #     `"pd-balanced"` or `"pd-ssd"`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] fs_type
  #   @return [::String]
  #     Optional. Type of file system that the disk should be formatted with.
  #     The workstation image must support this file system type. Must be empty
  #     if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set. Defaults to `"ext4"`.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. The [type of the persistent
  #     disk](https://cloud.google.com/compute/docs/disks#disk-types) for the
  #     home directory. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#size_gb size_gb}
  #     and
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#fs_type fs_type}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceRegionalPersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end

  # A Persistent Directory backed by a Compute Engine
  # [Hyperdisk Balanced High Availability
  # Disk](https://cloud.google.com/compute/docs/disks/hd-types/hyperdisk-balanced-ha).
  # This is a high-availability block storage solution that offers a balance
  # between performance and cost for most general-purpose workloads.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#size_gb size_gb}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceHyperdiskBalancedHighAvailability
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end
end

#gce_pd::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk

Returns A PersistentDirectory backed by a Compute Engine persistent disk.

Note: The following fields are mutually exclusive: gce_pd, gce_hd. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 781

class PersistentDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Persistent Directory backed by a Compute Engine regional persistent
  # disk. The
  # {::Google::Cloud::Workstations::V1beta::WorkstationConfig#persistent_directories persistent_directories}
  # field is repeated, but it may contain only one entry. It creates a
  # [persistent
  # disk](https://cloud.google.com/compute/docs/disks/persistent-disks) that
  # mounts to the workstation VM at `/home` when the session starts and
  # detaches when the session ends. If this field is empty, workstations
  # created with this configuration do not have a persistent home
  # directory.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`. If less than `200` GB, the
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#disk_type disk_type}
  #     must be
  #     `"pd-balanced"` or `"pd-ssd"`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] fs_type
  #   @return [::String]
  #     Optional. Type of file system that the disk should be formatted with.
  #     The workstation image must support this file system type. Must be empty
  #     if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set. Defaults to `"ext4"`.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. The [type of the persistent
  #     disk](https://cloud.google.com/compute/docs/disks#disk-types) for the
  #     home directory. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#size_gb size_gb}
  #     and
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#fs_type fs_type}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceRegionalPersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end

  # A Persistent Directory backed by a Compute Engine
  # [Hyperdisk Balanced High Availability
  # Disk](https://cloud.google.com/compute/docs/disks/hd-types/hyperdisk-balanced-ha).
  # This is a high-availability block storage solution that offers a balance
  # between performance and cost for most general-purpose workloads.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#size_gb size_gb}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceHyperdiskBalancedHighAvailability
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end
end

#mount_path::String

Returns Optional. Location of this directory in the running workstation.

Returns:

  • (::String)

    Optional. Location of this directory in the running workstation.



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 781

class PersistentDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Persistent Directory backed by a Compute Engine regional persistent
  # disk. The
  # {::Google::Cloud::Workstations::V1beta::WorkstationConfig#persistent_directories persistent_directories}
  # field is repeated, but it may contain only one entry. It creates a
  # [persistent
  # disk](https://cloud.google.com/compute/docs/disks/persistent-disks) that
  # mounts to the workstation VM at `/home` when the session starts and
  # detaches when the session ends. If this field is empty, workstations
  # created with this configuration do not have a persistent home
  # directory.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`. If less than `200` GB, the
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#disk_type disk_type}
  #     must be
  #     `"pd-balanced"` or `"pd-ssd"`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] fs_type
  #   @return [::String]
  #     Optional. Type of file system that the disk should be formatted with.
  #     The workstation image must support this file system type. Must be empty
  #     if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set. Defaults to `"ext4"`.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. The [type of the persistent
  #     disk](https://cloud.google.com/compute/docs/disks#disk-types) for the
  #     home directory. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#size_gb size_gb}
  #     and
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#fs_type fs_type}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceRegionalPersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end

  # A Persistent Directory backed by a Compute Engine
  # [Hyperdisk Balanced High Availability
  # Disk](https://cloud.google.com/compute/docs/disks/hd-types/hyperdisk-balanced-ha).
  # This is a high-availability block storage solution that offers a balance
  # between performance and cost for most general-purpose workloads.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#size_gb size_gb}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceHyperdiskBalancedHighAvailability
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end
end