Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

A Persistent Directory backed by a Compute Engine Hyperdisk Balanced High Availability Disk. This is a high-availability block storage solution that offers a balance between performance and cost for most general-purpose workloads.

Defined Under Namespace

Modules: ReclaimPolicy

Instance Attribute Summary collapse

Instance Attribute Details

#archive_timeout::Google::Protobuf::Duration

Returns Optional. Number of seconds to wait after initially creating or subsequently shutting down the workstation before converting its disk into a snapshot. This generally saves costs at the expense of greater startup time on next workstation start, as the service will need to create a disk from the archival snapshot.

A value of "0s" indicates that the disk will never be archived.

Returns:

  • (::Google::Protobuf::Duration)

    Optional. Number of seconds to wait after initially creating or subsequently shutting down the workstation before converting its disk into a snapshot. This generally saves costs at the expense of greater startup time on next workstation start, as the service will need to create a disk from the archival snapshot.

    A value of "0s" indicates that the disk will never be archived.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 904

class GceHyperdiskBalancedHighAvailability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Value representing what should happen to the disk after the workstation
  # is deleted.
  module ReclaimPolicy
    # Do not use.
    RECLAIM_POLICY_UNSPECIFIED = 0

    # Delete the persistent disk when deleting the workstation.
    DELETE = 1

    # Keep the persistent disk when deleting the workstation.
    # An administrator must manually delete the disk.
    RETAIN = 2
  end
end

#max_size_gb::Integer

Returns Optional. Maximum size in GB to which this persistent directory can be resized. Defaults to unlimited if not set.

Returns:

  • (::Integer)

    Optional. Maximum size in GB to which this persistent directory can be resized. Defaults to unlimited if not set.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 904

class GceHyperdiskBalancedHighAvailability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Value representing what should happen to the disk after the workstation
  # is deleted.
  module ReclaimPolicy
    # Do not use.
    RECLAIM_POLICY_UNSPECIFIED = 0

    # Delete the persistent disk when deleting the workstation.
    DELETE = 1

    # Keep the persistent disk when deleting the workstation.
    # An administrator must manually delete the disk.
    RETAIN = 2
  end
end

#reclaim_policy::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability::ReclaimPolicy

Returns Optional. Whether the persistent disk should be deleted when the workstation is deleted. Valid values are DELETE and RETAIN. Defaults to DELETE.

Returns:



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 904

class GceHyperdiskBalancedHighAvailability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Value representing what should happen to the disk after the workstation
  # is deleted.
  module ReclaimPolicy
    # Do not use.
    RECLAIM_POLICY_UNSPECIFIED = 0

    # Delete the persistent disk when deleting the workstation.
    DELETE = 1

    # Keep the persistent disk when deleting the workstation.
    # An administrator must manually delete the disk.
    RETAIN = 2
  end
end

#size_gb::Integer

Returns Optional. The GB capacity of a persistent home directory for each workstation created with this configuration. Must be empty if source_snapshot is set.

Valid values are 10, 50, 100, 200, 500, or 1000. Defaults to 200.

Returns:

  • (::Integer)

    Optional. The GB capacity of a persistent home directory for each workstation created with this configuration. Must be empty if source_snapshot is set.

    Valid values are 10, 50, 100, 200, 500, or 1000. Defaults to 200.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 904

class GceHyperdiskBalancedHighAvailability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Value representing what should happen to the disk after the workstation
  # is deleted.
  module ReclaimPolicy
    # Do not use.
    RECLAIM_POLICY_UNSPECIFIED = 0

    # Delete the persistent disk when deleting the workstation.
    DELETE = 1

    # Keep the persistent disk when deleting the workstation.
    # An administrator must manually delete the disk.
    RETAIN = 2
  end
end

#source_snapshot::String

Returns Optional. Name of the snapshot to use as the source for the disk. If set, size_gb must be empty. Must be formatted as ext4 file system with no partitions.

Returns:

  • (::String)

    Optional. Name of the snapshot to use as the source for the disk. If set, size_gb must be empty. Must be formatted as ext4 file system with no partitions.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 904

class GceHyperdiskBalancedHighAvailability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Value representing what should happen to the disk after the workstation
  # is deleted.
  module ReclaimPolicy
    # Do not use.
    RECLAIM_POLICY_UNSPECIFIED = 0

    # Delete the persistent disk when deleting the workstation.
    DELETE = 1

    # Keep the persistent disk when deleting the workstation.
    # An administrator must manually delete the disk.
    RETAIN = 2
  end
end