Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::PortRange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1beta/workstations.rb

Overview

A PortRange defines a range of ports. Both first and last are inclusive. To specify a single port, both first and last should be the same.

Instance Attribute Summary collapse

Instance Attribute Details

#first::Integer

Returns Required. Starting port number for the current range of ports. Valid ports are 22, 80, and ports within the range 1024-65535.

Returns:

  • (::Integer)

    Required. Starting port number for the current range of ports. Valid ports are 22, 80, and ports within the range 1024-65535.



1111
1112
1113
1114
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1111

class PortRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#last::Integer

Returns Required. Ending port number for the current range of ports. Valid ports are 22, 80, and ports within the range 1024-65535.

Returns:

  • (::Integer)

    Required. Ending port number for the current range of ports. Valid ports are 22, 80, and ports within the range 1024-65535.



1111
1112
1113
1114
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1111

class PortRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end