Class: Google::Cloud::Workstations::V1beta::CreateWorkstationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::CreateWorkstationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
Message for creating a CreateWorkstation.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#validate_only ⇒ ::Boolean
Optional.
-
#workstation ⇒ ::Google::Cloud::Workstations::V1beta::Workstation
Required.
-
#workstation_id ⇒ ::String
Required.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. Parent resource name.
1673 1674 1675 1676 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1673 class CreateWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. If set, validate the request and preview the result, but do not actually apply it.
1673 1674 1675 1676 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1673 class CreateWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#workstation ⇒ ::Google::Cloud::Workstations::V1beta::Workstation
Returns Required. Workstation to create. If source_workstation is specified, the
user must have workstations.workstations.use permission on the source
workstation, and the Cloud Workstations Service Agent for the project where
you are creating the new workstation must have compute.disks.createSnapshot
and compute.snapshots.useReadOnly on the source project.
1673 1674 1675 1676 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1673 class CreateWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#workstation_id ⇒ ::String
Returns Required. ID to use for the workstation.
1673 1674 1675 1676 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1673 class CreateWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |