Class: Google::Cloud::Workstations::V1beta::StopWorkstationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::StopWorkstationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
Request message for StopWorkstation.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag.
1749 1750 1751 1752 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1749 class StopWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Name of the workstation to stop.
1749 1750 1751 1752 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1749 class StopWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. If set, validate the request and preview the result, but do not actually apply it.
1749 1750 1751 1752 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1749 class StopWorkstationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |