Module: Google::Cloud::Workstations::V1beta::Workstation::State
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
Whether a workstation is running and ready to receive user requests.
Constant Summary collapse
- STATE_UNSPECIFIED =
Do not use.
0- STATE_STARTING =
The workstation is not yet ready to accept requests from users but will be soon.
1- STATE_RUNNING =
The workstation is ready to accept requests from users.
2- STATE_STOPPING =
The workstation is being stopped.
3- STATE_STOPPED =
The workstation is stopped and will not be able to receive requests until it is started.
4