Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::Host
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::WorkstationConfig::Host
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
Runtime host for a workstation.
Defined Under Namespace
Classes: GceInstance
Instance Attribute Summary collapse
-
#gce_instance ⇒ ::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance
Specifies a Compute Engine instance as the host.
Instance Attribute Details
#gce_instance ⇒ ::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance
Returns Specifies a Compute Engine instance as the host.
428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 428 class Host include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A runtime using a Compute Engine instance. # @!attribute [rw] machine_type # @return [::String] # Optional. The type of machine to use for VM instances—for example, # `"e2-standard-4"`. For more information about machine types that # Cloud Workstations supports, see the list of # [available machine # types](https://cloud.google.com/workstations/docs/available-machine-types). # @!attribute [rw] service_account # @return [::String] # Optional. The email address of the service account for Cloud # Workstations VMs created with this configuration. When specified, be # sure that the service account has `logging.logEntries.create` and # `monitoring.timeSeries.create` permissions on the project so it can # write logs out to Cloud Logging. If using a custom container image, the # service account must have [Artifact Registry # Reader](https://cloud.google.com/artifact-registry/docs/access-control#roles) # permission to pull the specified image. # # If you as the administrator want to be able to `ssh` into the # underlying VM, you need to set this value to a service account # for which you have the `iam.serviceAccounts.actAs` permission. # Conversely, if you don't want anyone to be able to `ssh` into the # underlying VM, use a service account where no one has that # permission. # # If not set, VMs run with a service account provided by the # Cloud Workstations service, and the image must be publicly # accessible. # @!attribute [rw] service_account_scopes # @return [::Array<::String>] # Optional. Scopes to grant to the # {::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance#service_account service_account}. # When specified, users of workstations under this configuration must # have `iam.serviceAccounts.actAs` on the service account. # @!attribute [rw] tags # @return [::Array<::String>] # Optional. Network tags to add to the Compute Engine VMs backing the # workstations. This option applies # [network # tags](https://cloud.google.com/vpc/docs/add-remove-network-tags) to VMs # created with this configuration. These network tags enable the creation # of [firewall # rules](https://cloud.google.com/workstations/docs/configure-firewall-rules). # @!attribute [rw] pool_size # @return [::Integer] # Optional. The number of VMs that the system should keep idle so that # new workstations can be started quickly for new users. Defaults to `0` # in the API. # @!attribute [r] pooled_instances # @return [::Integer] # Output only. Number of instances currently available in the pool for # faster workstation startup. # @!attribute [rw] disable_public_ip_addresses # @return [::Boolean] # Optional. When set to true, disables public IP addresses for VMs. If # you disable public IP addresses, you must set up Private Google Access # or Cloud NAT on your network. If you use Private Google Access and you # use `private.googleapis.com` or `restricted.googleapis.com` for # Container Registry and Artifact Registry, make sure that you set # up DNS records for domains `*.gcr.io` and `*.pkg.dev`. # Defaults to false (VMs have public IP addresses). # @!attribute [rw] enable_nested_virtualization # @return [::Boolean] # Optional. Whether to enable nested virtualization on Cloud Workstations # VMs created using this workstation configuration. # # Defaults to false. # # Nested virtualization lets you run virtual machine (VM) instances # inside your workstation. Before enabling nested virtualization, # consider the following important considerations. Cloud Workstations # instances are subject to the [same restrictions as Compute Engine # instances](https://cloud.google.com/compute/docs/instances/nested-virtualization/overview#restrictions): # # * **Organization policy**: projects, folders, or # organizations may be restricted from creating nested VMs if the # **Disable VM nested virtualization** constraint is enforced in # the organization policy. For more information, see the # Compute Engine section, # [Checking whether nested virtualization is # allowed](https://cloud.google.com/compute/docs/instances/nested-virtualization/managing-constraint#checking_whether_nested_virtualization_is_allowed). # * **Performance**: nested VMs might experience a 10% or greater # decrease in performance for workloads that are CPU-bound and # possibly greater than a 10% decrease for workloads that are # input/output bound. # * **Machine Type**: nested virtualization can only be enabled on # workstation configurations that specify a # {::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance#machine_type machine_type} # in the N1 or N2 machine series. # @!attribute [rw] shielded_instance_config # @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::GceShieldedInstanceConfig] # Optional. A set of Compute Engine Shielded instance options. # @!attribute [rw] confidential_instance_config # @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::GceConfidentialInstanceConfig] # Optional. A set of Compute Engine Confidential VM instance options. # @!attribute [rw] boot_disk_size_gb # @return [::Integer] # Optional. The size of the boot disk for the VM in gigabytes (GB). # The minimum boot disk size is `30` GB. Defaults to `50` GB. # @!attribute [rw] accelerators # @return [::Array<::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::Accelerator>] # Optional. A list of the type and count of accelerator cards attached to # the instance. # @!attribute [rw] boost_configs # @return [::Array<::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::BoostConfig>] # Optional. A list of the boost configurations that workstations created # using this workstation configuration are allowed to use. If specified, # users will have the option to choose from the list of boost configs # when starting a workstation. # @!attribute [rw] disable_ssh # @return [::Boolean] # Optional. Whether to disable SSH access to the VM. # @!attribute [rw] vm_tags # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. Resource manager tags to be bound to this instance. # Tag keys and values have the same definition as [resource manager # tags](https://cloud.google.com/resource-manager/docs/tags/tags-overview). # Keys must be in the format `tagKeys/{tag_key_id}`, and # values are in the format `tagValues/456`. # @!attribute [rw] reservation_affinity # @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::ReservationAffinity] # Optional. # [ReservationAffinity](https://cloud.google.com/compute/docs/instances/reserving-zonal-resources) # specifies a reservation that can be consumed to create VM # instances. If SPECIFIC_RESERVATION is specified, Cloud Workstations # will only create VMs in the zone where the reservation is located. # This would affect availability since the service will no longer be # resilient to zonal outages. If ANY_RESERVATION is specified, creating # reservations in both zones that the config creates VMs in will ensure # higher availability. # **Important Considerations for Reservation Affinity:** # # * This feature is intended for advanced users and requires # familiarity with Google Compute Engine reservations. # * Using reservations incurs charges, regardless of utilization. # * The resources in the pool will consume the specified # reservation. Take this into account when setting the # pool size. # @!attribute [rw] startup_script_uri # @return [::String] # Optional. Link to the startup script stored in Cloud Storage. This # script will be run on the host workstation VM when the VM is created. # The URI must be of the form gs://\\{bucket-name}/\\{object-name}. If # specifying a startup script, the service account must have [Permission # to access the bucket and script file in Cloud # Storage](https://cloud.google.com/storage/docs/access-control/iam-permissions). # Otherwise, the script must be publicly accessible. # Note that the service regularly updates the OS version of the host VM, # and it is the responsibility of the user to ensure the script stays # compatible with the OS version. # @!attribute [rw] instance_metadata # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. Custom metadata to apply to Compute Engine instances. class GceInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of Compute Engine Shielded instance options. # @!attribute [rw] enable_secure_boot # @return [::Boolean] # Optional. Whether the instance has Secure Boot enabled. # @!attribute [rw] enable_vtpm # @return [::Boolean] # Optional. Whether the instance has the vTPM enabled. # @!attribute [rw] enable_integrity_monitoring # @return [::Boolean] # Optional. Whether the instance has integrity monitoring enabled. class GceShieldedInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A set of Compute Engine Confidential VM instance options. # @!attribute [rw] enable_confidential_compute # @return [::Boolean] # Optional. Whether the instance has confidential compute enabled. class GceConfidentialInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An accelerator card attached to the instance. # @!attribute [rw] type # @return [::String] # Optional. Type of accelerator resource to attach to the instance, for # example, # `"nvidia-tesla-p100"`. # @!attribute [rw] count # @return [::Integer] # Optional. Number of accelerator cards exposed to the instance. class Accelerator include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A boost configuration is a set of resources that a workstation can use # to increase its performance. If you specify a boost configuration, upon # startup, workstation users can choose to use a VM provisioned under the # boost config by passing the boost config ID in the start request. If # the workstation user does not provide a boost config ID in the start # request, the system will choose a VM from the pool provisioned under # the default config. # @!attribute [rw] id # @return [::String] # Required. The ID to be used for the boost configuration. # @!attribute [rw] machine_type # @return [::String] # Optional. The type of machine that boosted VM instances will use—for # example, `e2-standard-4`. For more information about machine types # that Cloud Workstations supports, see the list of [available machine # types](https://cloud.google.com/workstations/docs/available-machine-types). # Defaults to `e2-standard-4`. # @!attribute [rw] accelerators # @return [::Array<::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::Accelerator>] # Optional. A list of the type and count of accelerator cards attached # to the boost instance. Defaults to `none`. # @!attribute [rw] boot_disk_size_gb # @return [::Integer] # Optional. The size of the boot disk for the VM in gigabytes (GB). # The minimum boot disk size is `30` GB. Defaults to `50` GB. # @!attribute [rw] enable_nested_virtualization # @return [::Boolean] # Optional. Whether to enable nested virtualization on boosted Cloud # Workstations VMs running using this boost configuration. # # Defaults to false. # # Nested virtualization lets you run virtual machine (VM) instances # inside your workstation. Before enabling nested virtualization, # consider the following important considerations. Cloud Workstations # instances are subject to the [same restrictions as Compute Engine # instances](https://cloud.google.com/compute/docs/instances/nested-virtualization/overview#restrictions): # # * **Organization policy**: projects, folders, or # organizations may be restricted from creating nested VMs if the # **Disable VM nested virtualization** constraint is enforced in # the organization policy. For more information, see the # Compute Engine section, # [Checking whether nested virtualization is # allowed](https://cloud.google.com/compute/docs/instances/nested-virtualization/managing-constraint#checking_whether_nested_virtualization_is_allowed). # * **Performance**: nested VMs might experience a 10% or greater # decrease in performance for workloads that are CPU-bound and # possibly greater than a 10% decrease for workloads that are # input/output bound. # * **Machine Type**: nested virtualization can only be enabled on # boost configurations that specify a # {::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::BoostConfig#machine_type machine_type} # in the N1 or N2 machine series. # @!attribute [rw] pool_size # @return [::Integer] # Optional. The number of boost VMs that the system should keep idle so # that workstations can be boosted quickly. Defaults to `0`. # @!attribute [rw] reservation_affinity # @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::ReservationAffinity] # Optional. # [ReservationAffinity](https://cloud.google.com/compute/docs/instances/reserving-zonal-resources) # specifies a reservation that can be consumed to create boost VM # instances. If SPECIFIC_RESERVATION is specified, Cloud Workstations # will only create VMs in the zone where the reservation is located. # This would affect availability since the service will no longer be # resilient to zonal outages. If ANY_RESERVATION is specified, creating # reservations in both zones that the config creates VMs in will ensure # higher availability. # **Important Considerations for Reservation Affinity:** # # * This feature is intended for advanced users and requires # familiarity with Google Compute Engine reservations. # * Using reservations incurs charges, regardless of utilization. # * The resources in the pool will consume the specified # reservation. Take this into account when setting the # pool size. class BoostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ReservationAffinity is the configuration of the desired reservation # from which instances can consume resources. # @!attribute [rw] consume_reservation_type # @return [::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::ReservationAffinity::Type] # Optional. Corresponds to the type of reservation consumption. # @!attribute [rw] key # @return [::String] # Optional. Corresponds to the label key of reservation resource. # @!attribute [rw] values # @return [::Array<::String>] # Optional. Corresponds to the label values of reservation resources. # Valid values are either the name of a reservation in the same project # or "projects/\\{project}/reservations/\\{reservation}" to target a shared # reservation in the same zone but in a different project. class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether to consume capacity from a reservation or not. module Type # Default value. This should not be used. TYPE_UNSPECIFIED = 0 # Do not consume from any reserved capacity. NO_RESERVATION = 1 # Consume any reservation available. ANY_RESERVATION = 2 # Must consume from a specific reservation. Must specify key value # fields for specifying the reservations. SPECIFIC_RESERVATION = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VmTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class InstanceMetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |