Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::ReservationAffinity
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::ReservationAffinity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
ReservationAffinity is the configuration of the desired reservation from which instances can consume resources.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#consume_reservation_type ⇒ ::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::ReservationAffinity::Type
Optional.
-
#key ⇒ ::String
Optional.
-
#values ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#consume_reservation_type ⇒ ::Google::Cloud::Workstations::V1beta::WorkstationConfig::Host::GceInstance::ReservationAffinity::Type
Returns Optional. Corresponds to the type of reservation consumption.
723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 723 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether to consume capacity from a reservation or not. module Type # Default value. This should not be used. TYPE_UNSPECIFIED = 0 # Do not consume from any reserved capacity. NO_RESERVATION = 1 # Consume any reservation available. ANY_RESERVATION = 2 # Must consume from a specific reservation. Must specify key value # fields for specifying the reservations. SPECIFIC_RESERVATION = 3 end end |
#key ⇒ ::String
Returns Optional. Corresponds to the label key of reservation resource.
723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 723 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether to consume capacity from a reservation or not. module Type # Default value. This should not be used. TYPE_UNSPECIFIED = 0 # Do not consume from any reserved capacity. NO_RESERVATION = 1 # Consume any reservation available. ANY_RESERVATION = 2 # Must consume from a specific reservation. Must specify key value # fields for specifying the reservations. SPECIFIC_RESERVATION = 3 end end |
#values ⇒ ::Array<::String>
Returns Optional. Corresponds to the label values of reservation resources. Valid values are either the name of a reservation in the same project or "projects/{project}/reservations/{reservation}" to target a shared reservation in the same zone but in a different project.
723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 723 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether to consume capacity from a reservation or not. module Type # Default value. This should not be used. TYPE_UNSPECIFIED = 0 # Do not consume from any reserved capacity. NO_RESERVATION = 1 # Consume any reservation available. ANY_RESERVATION = 2 # Must consume from a specific reservation. Must specify key value # fields for specifying the reservations. SPECIFIC_RESERVATION = 3 end end |