Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::HttpOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::WorkstationConfig::HttpOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
HTTP options for the running workstations.
Instance Attribute Summary collapse
-
#allowed_unauthenticated_cors_preflight_requests ⇒ ::Boolean
Optional.
-
#disable_localhost_replacement ⇒ ::Boolean
Optional.
Instance Attribute Details
#allowed_unauthenticated_cors_preflight_requests ⇒ ::Boolean
Returns Optional. By default, the workstations service makes sure that all requests to the workstation are authenticated. CORS preflight requests do not include cookies or custom headers, and so are considered unauthenticated and blocked by the workstations service. Enabling this option allows these unauthenticated CORS preflight requests through to the workstation, where it becomes the responsibility of the destination server in the workstation to validate the request.
1089 1090 1091 1092 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1089 class HttpOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disable_localhost_replacement ⇒ ::Boolean
Returns Optional. By default, the workstations service replaces references to localhost, 127.0.0.1, and 0.0.0.0 with the workstation's hostname in http responses from the workstation so that applications under development run properly on the workstation. This may intefere with some applications, and so this option allows that behavior to be disabled.
1089 1090 1091 1092 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 1089 class HttpOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |