Class: Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1beta/workstations.rb
Overview
A Persistent Directory backed by a Compute Engine regional persistent
disk. The
persistent_directories
field is repeated, but it may contain only one entry. It creates a
persistent
disk that
mounts to the workstation VM at /home when the session starts and
detaches when the session ends. If this field is empty, workstations
created with this configuration do not have a persistent home
directory.
Defined Under Namespace
Modules: ReclaimPolicy
Instance Attribute Summary collapse
-
#archive_timeout ⇒ ::Google::Protobuf::Duration
Optional.
-
#disk_type ⇒ ::String
Optional.
-
#fs_type ⇒ ::String
Optional.
-
#max_size_gb ⇒ ::Integer
Optional.
-
#reclaim_policy ⇒ ::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk::ReclaimPolicy
Optional.
-
#size_gb ⇒ ::Integer
Optional.
-
#source_snapshot ⇒ ::String
Optional.
Instance Attribute Details
#archive_timeout ⇒ ::Google::Protobuf::Duration
Returns Optional. Number of seconds to wait after initially creating or subsequently shutting down the workstation before converting its disk into a snapshot. This generally saves costs at the expense of greater startup time on next workstation start, as the service will need to create a disk from the archival snapshot.
A value of "0s" indicates that the disk will never be archived.
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 846 class GceRegionalPersistentDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Value representing what should happen to the disk after the workstation # is deleted. module ReclaimPolicy # Do not use. RECLAIM_POLICY_UNSPECIFIED = 0 # Delete the persistent disk when deleting the workstation. DELETE = 1 # Keep the persistent disk when deleting the workstation. # An administrator must manually delete the disk. RETAIN = 2 end end |
#disk_type ⇒ ::String
Returns Optional. The type of the persistent
disk for the
home directory. Defaults to "pd-standard".
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 846 class GceRegionalPersistentDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Value representing what should happen to the disk after the workstation # is deleted. module ReclaimPolicy # Do not use. RECLAIM_POLICY_UNSPECIFIED = 0 # Delete the persistent disk when deleting the workstation. DELETE = 1 # Keep the persistent disk when deleting the workstation. # An administrator must manually delete the disk. RETAIN = 2 end end |
#fs_type ⇒ ::String
Returns Optional. Type of file system that the disk should be formatted with.
The workstation image must support this file system type. Must be empty
if
source_snapshot
is set. Defaults to "ext4".
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 846 class GceRegionalPersistentDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Value representing what should happen to the disk after the workstation # is deleted. module ReclaimPolicy # Do not use. RECLAIM_POLICY_UNSPECIFIED = 0 # Delete the persistent disk when deleting the workstation. DELETE = 1 # Keep the persistent disk when deleting the workstation. # An administrator must manually delete the disk. RETAIN = 2 end end |
#max_size_gb ⇒ ::Integer
Returns Optional. Maximum size in GB to which this persistent directory can be resized. Defaults to unlimited if not set.
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 846 class GceRegionalPersistentDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Value representing what should happen to the disk after the workstation # is deleted. module ReclaimPolicy # Do not use. RECLAIM_POLICY_UNSPECIFIED = 0 # Delete the persistent disk when deleting the workstation. DELETE = 1 # Keep the persistent disk when deleting the workstation. # An administrator must manually delete the disk. RETAIN = 2 end end |
#reclaim_policy ⇒ ::Google::Cloud::Workstations::V1beta::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk::ReclaimPolicy
Returns Optional. Whether the persistent disk should be deleted when the
workstation is deleted. Valid values are DELETE and RETAIN.
Defaults to DELETE.
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 846 class GceRegionalPersistentDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Value representing what should happen to the disk after the workstation # is deleted. module ReclaimPolicy # Do not use. RECLAIM_POLICY_UNSPECIFIED = 0 # Delete the persistent disk when deleting the workstation. DELETE = 1 # Keep the persistent disk when deleting the workstation. # An administrator must manually delete the disk. RETAIN = 2 end end |
#size_gb ⇒ ::Integer
Returns Optional. The GB capacity of a persistent home directory for each workstation created with this configuration. Must be empty if source_snapshot is set.
Valid values are 10, 50, 100, 200, 500, or 1000.
Defaults to 200. If less than 200 GB, the
disk_type
must be
"pd-balanced" or "pd-ssd".
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 846 class GceRegionalPersistentDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Value representing what should happen to the disk after the workstation # is deleted. module ReclaimPolicy # Do not use. RECLAIM_POLICY_UNSPECIFIED = 0 # Delete the persistent disk when deleting the workstation. DELETE = 1 # Keep the persistent disk when deleting the workstation. # An administrator must manually delete the disk. RETAIN = 2 end end |
#source_snapshot ⇒ ::String
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/workstations/v1beta/workstations.rb', line 846 class GceRegionalPersistentDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Value representing what should happen to the disk after the workstation # is deleted. module ReclaimPolicy # Do not use. RECLAIM_POLICY_UNSPECIFIED = 0 # Delete the persistent disk when deleting the workstation. DELETE = 1 # Keep the persistent disk when deleting the workstation. # An administrator must manually delete the disk. RETAIN = 2 end end |